@@ -131,6 +131,7 @@ class BigQuery(Dialect):
 
         KEYWORDS = {
             **tokens.Tokenizer.KEYWORDS,
+            "ANY TYPE": TokenType.VARIANT,
             "BEGIN": TokenType.COMMAND,
             "BEGIN TRANSACTION": TokenType.BEGIN,
             "CURRENT_DATETIME": TokenType.CURRENT_DATETIME,
@@ -144,6 +145,11 @@ class BigQuery(Dialect):
         KEYWORDS.pop("DIV")
 
     class Parser(parser.Parser):
+        PREFIXED_PIVOT_COLUMNS = True
+
+        LOG_BASE_FIRST = False
+        LOG_DEFAULTS_TO_LN = True
+
         FUNCTIONS = {
             **parser.Parser.FUNCTIONS,  # type: ignore
             "DATE_TRUNC": lambda args: exp.DateTrunc(
@@ -202,13 +208,11 @@ class BigQuery(Dialect):
             ),
         }
 
-        LOG_BASE_FIRST = False
-        LOG_DEFAULTS_TO_LN = True
-
     class Generator(generator.Generator):
         EXPLICIT_UNION = True
         INTERVAL_ALLOWS_PLURAL_FORM = False
-        WITH_JOIN_HINT = False
+        JOIN_HINTS = False
+        TABLE_HINTS = False
         LIMIT_FETCH = "LIMIT"
 
         TRANSFORMS = {
@@ -265,8 +269,11 @@ class BigQuery(Dialect):
             exp.DataType.Type.NVARCHAR: "STRING",
             exp.DataType.Type.SMALLINT: "INT64",
             exp.DataType.Type.TEXT: "STRING",
+            exp.DataType.Type.TIMESTAMP: "DATETIME",
+            exp.DataType.Type.TIMESTAMPTZ: "TIMESTAMP",
             exp.DataType.Type.TINYINT: "INT64",
             exp.DataType.Type.VARCHAR: "STRING",
+            exp.DataType.Type.VARIANT: "ANY TYPE",
         }
 
         PROPERTIES_LOCATION = {
