@@ -140,7 +140,8 @@ class DuckDB(Dialect):
         }
 
     class Generator(generator.Generator):
-        WITH_JOIN_HINT = False
+        JOIN_HINTS = False
+        TABLE_HINTS = False
         STRUCT_DELIMITER = ("(", ")")
 
         TRANSFORMS = {
