@@ -248,6 +248,8 @@ class Postgres(Dialect):
             "$": TokenType.PARAMETER,
         }
 
+        VAR_SINGLE_TOKENS = {"$"}
+
     class Parser(parser.Parser):
         STRICT_CAST = False
 
@@ -285,7 +287,7 @@ class Postgres(Dialect):
         }
 
         def _parse_date_part(self) -> exp.Expression:
-            part = self._parse_var_or_string()
+            part = self._parse_type()
             self._match(TokenType.COMMA)
             value = self._parse_bitwise()
 
@@ -295,8 +297,10 @@ class Postgres(Dialect):
             return self.expression(exp.Extract, this=part, expression=value)
 
     class Generator(generator.Generator):
+        INTERVAL_ALLOWS_PLURAL_FORM = False
         LOCKING_READS_SUPPORTED = True
-        WITH_JOIN_HINT = False
+        JOIN_HINTS = False
+        TABLE_HINTS = False
         PARAMETER_TOKEN = "$"
 
         TYPE_MAPPING = {
