@@ -8,6 +8,10 @@ from sqlglot.helper import seq_get
 from sqlglot.tokens import TokenType
 
 
+def _json_sql(self, e) -> str:
+    return f'{self.sql(e, "this")}."{e.expression.name}"'
+
+
 class Redshift(Postgres):
     time_format = "'YYYY-MM-DD HH:MI:SS'"
     time_mapping = {
@@ -69,6 +73,7 @@ class Redshift(Postgres):
         SINGLE_TOKENS.pop("#")
 
     class Generator(Postgres.Generator):
+        LOCKING_READS_SUPPORTED = False
         SINGLE_STRING_INTERVAL = True
 
         TYPE_MAPPING = {
@@ -95,12 +100,16 @@ class Redshift(Postgres):
             ),
             exp.DistKeyProperty: lambda self, e: f"DISTKEY({e.name})",
             exp.DistStyleProperty: lambda self, e: self.naked_property(e),
+            exp.JSONExtract: _json_sql,
+            exp.JSONExtractScalar: _json_sql,
             exp.SortKeyProperty: lambda self, e: f"{'COMPOUND ' if e.args['compound'] else ''}SORTKEY({self.format_args(*e.this)})",
         }
 
         # Redshift uses the POW | POWER (expr1, expr2) syntax instead of expr1 ^ expr2 (postgres)
         TRANSFORMS.pop(exp.Pow)
 
+        RESERVED_KEYWORDS = {*Postgres.Generator.RESERVED_KEYWORDS, "snapshot"}
+
         def values_sql(self, expression: exp.Values) -> str:
             """
             Converts `VALUES...` expression into a series of unions.
