@@ -177,6 +177,8 @@ class Snowflake(Dialect):
     }
 
     class Parser(parser.Parser):
+        QUOTED_PIVOT_COLUMNS = True
+
         FUNCTIONS = {
             **parser.Parser.FUNCTIONS,
             "ARRAYAGG": exp.ArrayAgg.from_arg_list,
@@ -278,7 +280,8 @@ class Snowflake(Dialect):
         PARAMETER_TOKEN = "$"
         MATCHED_BY_SOURCE = False
         SINGLE_STRING_INTERVAL = True
-        WITH_JOIN_HINT = False
+        JOIN_HINTS = False
+        TABLE_HINTS = False
 
         TRANSFORMS = {
             **generator.Generator.TRANSFORMS,  # type: ignore
@@ -302,6 +305,7 @@ class Snowflake(Dialect):
             exp.Max: max_or_greatest,
             exp.Min: min_or_least,
             exp.PartitionedByProperty: lambda self, e: f"PARTITION BY {self.sql(e, 'this')}",
+            exp.StarMap: rename_func("OBJECT_CONSTRUCT"),
             exp.StrPosition: lambda self, e: self.func(
                 "POSITION", e.args.get("substr"), e.this, e.args.get("position")
             ),
