@@ -38,7 +38,8 @@ class SQLite(Dialect):
         }
 
     class Generator(generator.Generator):
-        WITH_JOIN_HINT = False
+        JOIN_HINTS = False
+        TABLE_HINTS = False
 
         TYPE_MAPPING = {
             **generator.Generator.TYPE_MAPPING,  # type: ignore
