@@ -131,7 +131,8 @@ class Teradata(Dialect):
             return cast
 
     class Generator(generator.Generator):
-        WITH_JOIN_HINT = False
+        JOIN_HINTS = False
+        TABLE_HINTS = False
 
         TYPE_MAPPING = {
             **generator.Generator.TYPE_MAPPING,  # type: ignore
