@@ -210,10 +210,11 @@ class Generator:
         exp.WithJournalTableProperty: exp.Properties.Location.POST_NAME,
     }
 
-    WITH_JOIN_HINT = True
+    JOIN_HINTS = True
+    TABLE_HINTS = True
 
+    RESERVED_KEYWORDS: t.Set[str] = set()
     WITH_SEPARATED_COMMENTS = (exp.Select, exp.From, exp.Where, exp.With)
-
     UNWRAPPED_INTERVAL_VALUES = (exp.Literal, exp.Paren, exp.Column)
 
     SENTINEL_LINE_BREAK = "__SQLGLOT__LB__"
@@ -809,9 +810,14 @@ class Generator:
 
     def identifier_sql(self, expression: exp.Identifier) -> str:
         text = expression.name
-        text = text.lower() if self.normalize and not expression.quoted else text
+        lower = text.lower()
+        text = lower if self.normalize and not expression.quoted else text
         text = text.replace(self.identifier_end, self._escaped_identifier_end)
-        if expression.quoted or should_identify(text, self.identify):
+        if (
+            expression.quoted
+            or should_identify(text, self.identify)
+            or lower in self.RESERVED_KEYWORDS
+        ):
             text = f"{self.identifier_start}{text}{self.identifier_end}"
         return text
 
@@ -1034,9 +1040,10 @@ class Generator:
             self.sql(expression, "partition") if expression.args.get("partition") else ""
         )
         expression_sql = self.sql(expression, "expression")
+        conflict = self.sql(expression, "conflict")
         returning = self.sql(expression, "returning")
         sep = self.sep() if partition_sql else ""
-        sql = f"INSERT{alternative}{this}{exists}{partition_sql}{sep}{expression_sql}{returning}"
+        sql = f"INSERT{alternative}{this}{exists}{partition_sql}{sep}{expression_sql}{conflict}{returning}"
         return self.prepend_ctes(expression, sql)
 
     def intersect_sql(self, expression: exp.Intersect) -> str:
@@ -1054,6 +1061,19 @@ class Generator:
     def pseudotype_sql(self, expression: exp.PseudoType) -> str:
         return expression.name.upper()
 
+    def onconflict_sql(self, expression: exp.OnConflict) -> str:
+        conflict = "ON DUPLICATE KEY" if expression.args.get("duplicate") else "ON CONFLICT"
+        constraint = self.sql(expression, "constraint")
+        if constraint:
+            constraint = f"ON CONSTRAINT {constraint}"
+        key = self.expressions(expression, key="key", flat=True)
+        do = "" if expression.args.get("duplicate") else " DO "
+        nothing = "NOTHING" if expression.args.get("nothing") else ""
+        expressions = self.expressions(expression, flat=True)
+        if expressions:
+            expressions = f"UPDATE SET {expressions}"
+        return f"{self.seg(conflict)} {constraint}{key}{do}{nothing}{expressions}"
+
     def returning_sql(self, expression: exp.Returning) -> str:
         return f"{self.seg('RETURNING')} {self.expressions(expression, flat=True)}"
 
@@ -1086,7 +1106,7 @@ class Generator:
         alias = self.sql(expression, "alias")
         alias = f"{sep}{alias}" if alias else ""
         hints = self.expressions(expression, key="hints", sep=", ", flat=True)
-        hints = f" WITH ({hints})" if hints else ""
+        hints = f" WITH ({hints})" if hints and self.TABLE_HINTS else ""
         laterals = self.expressions(expression, key="laterals", sep="")
         joins = self.expressions(expression, key="joins", sep="")
         pivots = self.expressions(expression, key="pivots", sep="")
@@ -1206,7 +1226,7 @@ class Generator:
                     "NATURAL" if expression.args.get("natural") else None,
                     expression.side,
                     expression.kind,
-                    expression.hint if self.WITH_JOIN_HINT else None,
+                    expression.hint if self.JOIN_HINTS else None,
                     "JOIN",
                 )
                 if op
@@ -1533,12 +1553,18 @@ class Generator:
         spec_sql = " " + self.window_spec_sql(spec) if spec else ""
 
         alias = self.sql(expression, "alias")
-        this = f"{this} {'AS' if expression.arg_key == 'windows' else 'OVER'}"
+        over = self.sql(expression, "over") or "OVER"
+        this = f"{this} {'AS' if expression.arg_key == 'windows' else over}"
+
+        first = expression.args.get("first")
+        if first is not None:
+            first = " FIRST " if first else " LAST "
+        first = first or ""
 
         if not partition and not order and not spec and alias:
             return f"{this} {alias}"
 
-        window_args = alias + partition_sql + order_sql + spec_sql
+        window_args = alias + first + partition_sql + order_sql + spec_sql
 
         return f"{this} ({window_args.strip()})"
 
@@ -1567,7 +1593,7 @@ class Generator:
         return f"{this} BETWEEN {low} AND {high}"
 
     def bracket_sql(self, expression: exp.Bracket) -> str:
-        expressions = apply_index_offset(expression.expressions, self.index_offset)
+        expressions = apply_index_offset(expression.this, expression.expressions, self.index_offset)
         expressions_sql = ", ".join(self.sql(e) for e in expressions)
 
         return f"{self.sql(expression, 'this')}[{expressions_sql}]"
@@ -1609,6 +1635,11 @@ class Generator:
         expressions = self.expressions(expression, flat=True)
         return f"CONSTRAINT {this} {expressions}"
 
+    def nextvaluefor_sql(self, expression: exp.NextValueFor) -> str:
+        order = expression.args.get("order")
+        order = f" OVER ({self.order_sql(order, flat=True)})" if order else ""
+        return f"NEXT VALUE FOR {self.sql(expression, 'this')}{order}"
+
     def extract_sql(self, expression: exp.Extract) -> str:
         this = self.sql(expression, "this")
         expression_sql = self.sql(expression, "expression")
