@@ -1,11 +1,15 @@
 from sqlglot import exp
 from sqlglot.helper import tsort
-from sqlglot.optimizer.simplify import simplify
 
 
 def optimize_joins(expression):
     """
     Removes cross joins if possible and reorder joins based on predicate dependencies.
+
+    Example:
+        >>> from sqlglot import parse_one
+        >>> optimize_joins(parse_one("SELECT * FROM x CROSS JOIN y JOIN z ON x.a = z.a AND y.a = z.a")).sql()
+        'SELECT * FROM x JOIN z ON x.a = z.a AND TRUE JOIN y ON y.a = z.a'
     """
     for select in expression.find_all(exp.Select):
         references = {}
@@ -24,7 +28,6 @@ def optimize_joins(expression):
         for name, join in cross_joins:
             for dep in references.get(name, []):
                 on = dep.args["on"]
-                on = on.replace(simplify(on))
 
                 if isinstance(on, exp.Connector):
                     for predicate in on.flatten():
